@@ -34,7 +34,7 @@
 #include "atk-enum-types.h"
 #include "atkintl.h"
 
-GPtrArray *extra_roles = NULL;
+static GPtrArray *extra_roles = NULL;
 
 enum
 {
@@ -1318,9 +1318,13 @@ atk_role_get_localized_name (AtkRole role)
 #ifdef ENABLE_NLS
   if (!gettext_initialized)
     {
-      gettext_initialized = TRUE;
+      const char *dir = g_getenv ("ATK_ALT_LOCALEDIR");
 
-      bindtextdomain (GETTEXT_PACKAGE, ATK_LOCALEDIR);
+      gettext_initialized = TRUE;
+      if (dir == NULL)
+        dir = ATK_LOCALEDIR;
+
+      bindtextdomain (GETTEXT_PACKAGE, dir);
 #ifdef HAVE_BIND_TEXTDOMAIN_CODESET
       bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
